Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(220)

Unified Diff: tools/testing/dart/test_options.dart

Issue 9086008: Add python wrapper for test.dart. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments Created 8 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/test_wrapper.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/testing/dart/test_options.dart
diff --git a/tools/testing/dart/test_options.dart b/tools/testing/dart/test_options.dart
index 0d6e72104c2ba26b03e0ae059a0104ef2aabc10f..654138320050b4a44fedde74742e3c0cdbe0aad8 100644
--- a/tools/testing/dart/test_options.dart
+++ b/tools/testing/dart/test_options.dart
@@ -294,8 +294,9 @@ is 'dart file.dart' and you specify special command
configuration['special-command'] = 'python -u $valgrind @';
}
- // Use verbose progress indication for verbose output.
- if (configuration['verbose']) {
+ // Use verbose progress indication for verbose output unless buildbot
+ // progress indication is requested.
+ if (configuration['verbose'] && configuration['progress'] != 'buildbot') {
configuration['progress'] = 'verbose';
}
« no previous file with comments | « tools/test_wrapper.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698